==> haskell-hls-refactor-plugin-1.1.0.0-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-refactor-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-refactor-plugin-1.1.0.0-E6fGrGbkigWBGEGVP3cpOc
key:                  hls-refactor-plugin-1.1.0.0-E6fGrGbkigWBGEGVP3cpOc
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6357306e2c276528997d305c19bc67d6
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-refactor-plugin-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-refactor-plugin-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-1.1.0.0-E6fGrGbkigWBGEGVP3cpOc
depends:
    aeson-2.1.2.1-CCP80pZvZcA8gRL3g3IUms base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB deepseq-1.4.6.1
    dlist-1.0-HCxoMn9TirQDgPCFxho7O extra-1.7.15-AGUYw6GbrLRLwm4dZiS6ZK
    ghc-9.2.8 ghc-boot-9.2.8
    ghc-exactprint-1.5.0-GPbgHgfyJRe9qn3EQAIQeg
    ghcide-1.9.1.0-HcE6TgqMvfILiAJoj4uRRs
    hls-graph-1.9.0.0-7QA4w8QIPhnBZZwGMwXZZx
    hls-plugin-api-1.6.0.0-DZacf9A5YhkGz37davT3qW
    lens-5.2.3-9JgBadUMk8EJFrj4zp8J3r
    lsp-1.6.0.0-G8lK0z7QLLeI7S4hhuqfUC mtl-2.2.2
    regex-tdfa-1.3.2.2-8Eko8V8XkdOF8ZvUlcVNQI
    retrie-1.2.2-JT2kJqp7tRoITXWIyomhPO
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3 text-1.2.5.0
    text-rope-0.2-4ZBoIy9kyY22Yey9mop6N7 time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-A3yVeSkjdcGAgke7XFfywE

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refactor-plugin-1.1.0.0-185-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-refactor-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-refactor-plugin-1.1.0.0-A9Xh9R7pFkM3Zq6xU5vQdU
key:                  hls-refactor-plugin-1.1.0.0-A9Xh9R7pFkM3Zq6xU5vQdU
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  69b577b573791d3de5fe5020366da2d8
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-refactor-plugin-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-refactor-plugin-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-1.1.0.0-A9Xh9R7pFkM3Zq6xU5vQdU
depends:
    aeson-2.1.2.1-CCP80pZvZcA8gRL3g3IUms base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB deepseq-1.4.6.1
    dlist-1.0-HCxoMn9TirQDgPCFxho7O extra-1.7.15-AGUYw6GbrLRLwm4dZiS6ZK
    ghc-9.2.8 ghc-boot-9.2.8
    ghc-exactprint-1.5.0-GPbgHgfyJRe9qn3EQAIQeg
    ghcide-1.9.1.0-GZf1bbQf5HHAIqBun3BDWk
    hls-graph-1.9.0.0-7QA4w8QIPhnBZZwGMwXZZx
    hls-plugin-api-1.6.0.0-DZacf9A5YhkGz37davT3qW
    lens-5.2.3-9JgBadUMk8EJFrj4zp8J3r
    lsp-1.6.0.0-G8lK0z7QLLeI7S4hhuqfUC mtl-2.2.2
    regex-tdfa-1.3.2.2-8Eko8V8XkdOF8ZvUlcVNQI
    retrie-1.2.2-JT2kJqp7tRoITXWIyomhPO
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3 text-1.2.5.0
    text-rope-0.2-4ZBoIy9kyY22Yey9mop6N7 time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-A3yVeSkjdcGAgke7XFfywE

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
